@@ -470,5 +470,16 @@ class SubParameter(unittest.TestCase):
         req.close()
 
 
+class SetString(unittest.TestCase):
+    def test(self):
+        parameter_tree = motorcortex.ParameterTree()
+        # Open request and subscribe connection
+        req, sub = motorcortex.connect("wss://localhost:5568:5567", motorcortex.MessageTypes(), parameter_tree,
+                                       certificate="mcx.crt.pem", timeout_ms=1000,
+                                       login="root", password="secret")
+        res = req.setParameter("root/Control/dummyChar", "Hallo robot!")
+        res.get();
+
+
 if __name__ == '__main__':
     unittest.main()
